Getting started
===============

In this guide you will learn how to quickly get started using the NetQASM SDK and to run your applications on a simulator of a quantum network.
Before continuing, make sure you have followed the :ref:`installation`.
We will be using the simulator :squidasm:`SquidASM <>`, (see :ref:`installation`).
To make sure that you're ready to go run

.. code-block:: bash
   
   python3 -c "import squidasm; print(squidasm.__version__)"

In the next part, :ref:`first-app`, we will run our first app.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart/first-app
   quickstart/using-sdk
   quickstart/file_structure
   quickstart/modules
